@@ -1,10 +1,10 @@
 from auth_token.contrib.common.default.views import TokenLogoutView
+from auth_token.utils import is_installed_security
 
-try:
-    import security
+if is_installed_security:
     from auth_token.contrib.common.auth_security.views import InputLogMixin, TokenLoginView
     from auth_token.contrib.common.auth_security.views import LoginCodeVerificationView as _LoginCodeVerificationView
-except ImportError:
+else:
     from auth_token.contrib.common.default.views import InputLogMixin, TokenLoginView
     from django.contrib.auth.views import LoginView as _LoginCodeVerificationView
 
